@@ -289,6 +289,10 @@ if [ $? -ne 0 ]; then
     exit 1
 fi
 
+if [ $(expr ${QUARTUS_VER[major]} \>= 19 ) -eq 1 ]; then
+   export PERL5LIB=$(echo ${QUARTUS_ROOTDIR}/linux64/perl/lib/*.*/)
+fi
+
 nios_system=../fpga/ip/altera/nios_system
 
 # 9a484b436: Windows-specific workaround for Quartus bug
@@ -337,6 +341,7 @@ else
     cmd="${cmd}; set device ${DEVICE}"
     cmd="${cmd}; set nios_impl ${nios_rev}"
     cmd="${cmd}; set ram_size $(get_qsys_ram $size)"
+    cmd="${cmd}; set platform_revision ${rev}"
     qsys-script \
         --script=${build_dir}/nios_system.tcl \
         --cmd="${cmd}"
@@ -401,6 +406,16 @@ make WORKDIR=${work_dir} \
 
 popd
 
+if [ "$rev" == "foxhunt" ]; then
+    pushd ${build_dir}/../software/foxhunt/
+
+    make WORKDIR=${work_dir} \
+         mem_init_clean \
+         mem_init_generate
+
+    popd
+fi
+
 echo ""
 echo "##########################################################################"
 echo "    Building ${board} FPGA Image: $rev, $size kLE"
