@@ -175,7 +175,7 @@ classdef bladeRF < handle
             end
 
             if count > 0
-                devs = repmat(struct('backend', [], 'serial', [], 'usb_bus', [], 'usb_addr', [], 'instance', []), 1, count);
+                devs = repmat(struct('backend', [], 'serial', [], 'usb_bus', [], 'usb_addr', [], 'instance', [], 'manufacturer', [], 'product', []), 1, count);
                 for x = 0:(count-1)
                     ptr = pdevlist+x;
                     devs(x+1) = ptr.Value;
@@ -250,8 +250,8 @@ classdef bladeRF < handle
         %   - libusb-1.0.dll and/or CyUSB.dll
         %   - pthreadVC2.dll
         %
-        % Linux users will need to copy libbladeRF.h to this directory
-        % and add the following to it, after "#define BLADERF_H_"
+        % Linux users will need to copy libbladeRF.h, bladeRF1.h, bladeRF2.h to this directory
+        % and add the following #define to libbladeRF.h, after "#define BLADERF_H_" or "#define LIBBLADERF_H"
         %
         % #define MATLAB_LINUX_THUNK_BUILD_
         %
@@ -262,13 +262,34 @@ classdef bladeRF < handle
             arch = computer('arch');
             this_dir = pwd;
             proto_output = 'delete_this_file';
+            if size(dir('*bladeRF*.h'), 1) < 3
+                help bladeRF.build_thunk
+                warning('Ensure libbladeRF.h, bladeRF1.h, and bladeRF2.h exist in this directory. Please review instructions.')
+                return
+            end
             switch arch
                 case 'win64'
                     [notfound, warnings] = loadlibrary('bladeRF', 'libbladeRF.h', 'includepath', this_dir, 'addheader', 'stdbool.h', 'addheader', 'bladeRF1.h', 'addheader', 'bladeRF2.h', 'alias', 'libbladeRF', 'notempdir', 'mfilename', proto_output);
                 case 'glnxa64'
-                    [notfound, warnings] = loadlibrary('libbladeRF', 'libbladeRF.h', 'includepath', this_dir, 'notempdir', 'mfilename', proto_output);
+                    hnd = fopen('libbladeRF.h');
+                    found = false;
+                    if hnd > 0
+                        while ~ feof(hnd)
+                            if strfind(fgetl(hnd), '#define MATLAB_LINUX_THUNK_BUILD_') == 1
+                                found = true;
+                                break;
+                            end
+                        end
+                        fclose(hnd);
+                    end
+                    if ~ found
+                        help bladeRF.build_thunk
+                        warning('Could not find required #define in libbladeRF.h . Please review instructions.');
+                        return
+                    end
+                    [notfound, warnings] = loadlibrary('libbladeRF', 'libbladeRF.h', 'includepath', this_dir, 'addheader', 'stdbool.h', 'addheader', 'bladeRF1.h', 'addheader', 'bladeRF2.h', 'alias', 'libbladeRF', 'notempdir', 'mfilename', proto_output);
                 case 'maci64'
-                    [notfound, warnings] = loadlibrary('libbladeRF.dylib', 'libbladeRF.h', 'includepath', this_dir, 'notempdir', 'mfilename', proto_output);
+                    [notfound, warnings] = loadlibrary('libbladeRF.dylib', 'libbladeRF.h', 'includepath', this_dir, 'addheader', 'stdbool.h', 'addheader', 'bladeRF1.h', 'addheader', 'bladeRF2.h', 'alias', 'libbladeRF', 'notempdir', 'mfilename', proto_output);
                 otherwise
                     error(strcat('Unsupported architecture: ', arch))
             end
@@ -287,6 +308,13 @@ classdef bladeRF < handle
             if isempty(warnings) == false
                 warning('Encountered the following warnings while loading libbladeRF:\n%s\n', warnings);
             end
+
+            warning('Restart program after running bladeRF.build_thunk()')
+            if isempty(strfind([path],pwd))
+                warning('Could not find current directory in path.')
+                warning('Consider saving this directory to path by trying:')
+                warning('    addpath(pwd) ; savepath')
+            end
         end
     end
 
@@ -483,6 +511,9 @@ classdef bladeRF < handle
                 case 'BLADERF_FPGA_A4'
                     obj.info.fpga_size = 'A4 49 kLE';
                     obj.info.gen = 2;
+                case 'BLADERF_FPGA_A5'
+                    obj.info.fpga_size = 'A5 77 kLE';
+                    obj.info.gen = 2;
                 case 'BLADERF_FPGA_A9'
                     obj.info.fpga_size = 'A9 301 kLE';
                     obj.info.gen = 2;
