@@ -16,91 +16,68 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
-#include <stdlib.h>
-#include <string.h>
-#include <stdio.h>
 #include <errno.h>
 #include <pthread.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include "cmd.h"
 #include "conversions.h"
+#include "parse.h"
 #include "script.h"
 #include "thread.h"
 
 #include "doc/cmd_help.h"
 
-#define DECLARE_CMD(x) int cmd_##x (struct cli_state *, int, char **)
-DECLARE_CMD(calibrate);
-DECLARE_CMD(clear);
-DECLARE_CMD(echo);
-DECLARE_CMD(erase);
-DECLARE_CMD(flash_backup);
-DECLARE_CMD(flash_image);
-DECLARE_CMD(flash_init_cal);
-DECLARE_CMD(flash_restore);
-DECLARE_CMD(fw_log);
-DECLARE_CMD(help);
-DECLARE_CMD(info);
-DECLARE_CMD(jump_to_bootloader);
-DECLARE_CMD(load);
-DECLARE_CMD(xb);
-DECLARE_CMD(mimo);
-DECLARE_CMD(open);
-DECLARE_CMD(peek);
-DECLARE_CMD(poke);
-DECLARE_CMD(print);
-DECLARE_CMD(probe);
-DECLARE_CMD(recover);
-DECLARE_CMD(run);
-DECLARE_CMD(set);
-DECLARE_CMD(rx);
-DECLARE_CMD(trigger);
-DECLARE_CMD(tx);
-DECLARE_CMD(version);
+#define DECLARE_CMD(x, ...)                        \
+    int cmd_##x(struct cli_state *, int, char **); \
+    static char const *cmd_names_##x[] = { __VA_ARGS__, NULL };
 
-#define MAX_ARGS    10
+DECLARE_CMD(calibrate, "calibrate", "cal");
+DECLARE_CMD(clear, "clear", "cls");
+DECLARE_CMD(echo, "echo");
+DECLARE_CMD(erase, "erase", "e");
+DECLARE_CMD(flash_backup, "flash_backup", "fb");
+DECLARE_CMD(flash_image, "flash_image", "fi");
+DECLARE_CMD(flash_init_cal, "flash_init_cal", "fic");
+DECLARE_CMD(flash_restore, "flash_restore", "fr");
+DECLARE_CMD(fw_log, "fw_log");
+DECLARE_CMD(help, "help", "h", "?");
+DECLARE_CMD(info, "info", "i");
+DECLARE_CMD(jump_to_bootloader, "jump_to_boot", "j");
+DECLARE_CMD(load, "load", "ld");
+DECLARE_CMD(mimo, "mimo");
+DECLARE_CMD(open, "open", "op", "o");
+DECLARE_CMD(peek, "peek", "pe");
+DECLARE_CMD(poke, "poke", "po");
+DECLARE_CMD(print, "print", "pr", "p");
+DECLARE_CMD(probe, "probe", "pro");
+DECLARE_CMD(quit, "quit", "q", "exit", "x");
+DECLARE_CMD(recover, "recover", "r");
+DECLARE_CMD(run, "run");
+DECLARE_CMD(rx, "rx", "receive");
+DECLARE_CMD(set, "set", "s");
+DECLARE_CMD(trigger, "trigger", "tr");
+DECLARE_CMD(tx, "tx", "transmit");
+DECLARE_CMD(version, "version", "ver", "v");
+DECLARE_CMD(xb, "xb");
+
+#define MAX_ARGS 10
 #define COMMENT_CHAR '#'
 
 struct cmd {
-    const char **names;
+    char const **names;
     int (*exec)(struct cli_state *s, int argc, char **argv);
-    const char  *desc;
-    const char  *help;
-    bool        requires_device;
-    bool        requires_fpga;
-    bool        allow_while_streaming;
+    char const *desc;
+    char const *help;
+    bool requires_device;
+    bool requires_fpga;
+    bool allow_while_streaming;
 };
 
-static const char *cmd_names_calibrate[] = { "calibrate", "cal", NULL };
-static const char *cmd_names_clear[] = { "clear", "cls", NULL };
-static const char *cmd_names_echo[] = { "echo", NULL };
-static const char *cmd_names_erase[] = { "erase", "e", NULL };
-static const char *cmd_names_flash_backup[] = { "flash_backup", "fb",  NULL };
-static const char *cmd_names_flash_image[] = { "flash_image", "fi", NULL };
-static const char *cmd_names_flash_init_cal[] = { "flash_init_cal", "fic", NULL };
-static const char *cmd_names_flash_restore[] = { "flash_restore", "fr", NULL };
-static const char *cmd_names_fw_log[] = { "fw_log", NULL };
-static const char *cmd_names_help[] = { "help", "h", "?", NULL };
-static const char *cmd_names_info[] = { "info", "i", NULL };
-static const char *cmd_names_jump[] = { "jump_to_boot", "j", NULL };
-static const char *cmd_names_load[] = { "load", "ld", NULL };
-static const char *cmd_names_xb[] = { "xb", NULL };
-static const char *cmd_names_mimo[] = { "mimo", NULL };
-static const char *cmd_names_open[] = { "open", "op", "o", NULL };
-static const char *cmd_names_peek[] = { "peek", "pe", NULL };
-static const char *cmd_names_poke[] = { "poke", "po", NULL };
-static const char *cmd_names_print[] = { "print", "pr", "p", NULL };
-static const char *cmd_names_probe[] = { "probe", "pro", NULL };
-static const char *cmd_names_quit[] = { "quit", "q", "exit", "x", NULL };
-static const char *cmd_names_rec[] = { "recover", "r", NULL };
-static const char *cmd_names_run[] = { "run", NULL };
-static const char *cmd_names_rx[] = { "rx", "receive", NULL };
-static const char *cmd_names_trigger[] = { "trigger", "tr", NULL};
-static const char *cmd_names_tx[] = { "tx", "transmit", NULL };
-static const char *cmd_names_set[] = { "set", "s", NULL };
-static const char *cmd_names_ver[] = { "version", "ver", "v", NULL };
-
-static const struct cmd cmd_table[] = {
+// clang-format off
+static struct cmd const cmd_table[] = {
     {
         FIELD_INIT(.names, cmd_names_calibrate),
         FIELD_INIT(.exec, cmd_calibrate),
@@ -149,12 +126,32 @@ static const struct cmd cmd_table[] = {
     {
         FIELD_INIT(.names, cmd_names_flash_image),
         FIELD_INIT(.exec, cmd_flash_image),
-        FIELD_INIT(.desc, "Print a flash image's metadata or create a new flash image"),
+        FIELD_INIT(.desc, "Print a flash image's metadata or create a new "
+                          "flash image"),
         FIELD_INIT(.help, CLI_CMD_HELPTEXT_flash_image),
         FIELD_INIT(.requires_device, false),
         FIELD_INIT(.requires_fpga, false),
         FIELD_INIT(.allow_while_streaming, false),
     },
+    {
+        FIELD_INIT(.names, cmd_names_flash_init_cal),
+        FIELD_INIT(.exec, cmd_flash_init_cal),
+        FIELD_INIT(.desc, "Write new calibration data to a device or to a "
+                          "file"),
+        FIELD_INIT(.help, CLI_CMD_HELPTEXT_flash_init_cal),
+        FIELD_INIT(.requires_device, true),
+        FIELD_INIT(.requires_fpga, false),
+        FIELD_INIT(.allow_while_streaming, false),
+    },
+    {
+        FIELD_INIT(.names, cmd_names_flash_restore),
+        FIELD_INIT(.exec, cmd_flash_restore),
+        FIELD_INIT(.desc, "Restore flash data from a file"),
+        FIELD_INIT(.help, CLI_CMD_HELPTEXT_flash_restore),
+        FIELD_INIT(.requires_device, true),
+        FIELD_INIT(.requires_fpga, false),
+        FIELD_INIT(.allow_while_streaming, false),
+    },
     {
         FIELD_INIT(.names, cmd_names_fw_log),
         FIELD_INIT(.exec, cmd_fw_log),
@@ -164,24 +161,6 @@ static const struct cmd cmd_table[] = {
         FIELD_INIT(.requires_fpga, false),
         FIELD_INIT(.allow_while_streaming, true),
     },
-    {
-        FIELD_INIT(.names, cmd_names_flash_init_cal),
-        FIELD_INIT(.exec, cmd_flash_init_cal),
-        FIELD_INIT(.desc, "Write new calibration data to a device or to a file"),
-        FIELD_INIT(.help, CLI_CMD_HELPTEXT_flash_init_cal),
-        FIELD_INIT(.requires_device, true),
-        FIELD_INIT(.requires_fpga, true),
-        FIELD_INIT(.allow_while_streaming, false),
-    },
-    {
-        FIELD_INIT(.names, cmd_names_flash_restore),
-        FIELD_INIT(.exec, cmd_flash_restore),
-        FIELD_INIT(.desc, "Restore flash data from a file"),
-        FIELD_INIT(.help, CLI_CMD_HELPTEXT_flash_restore),
-        FIELD_INIT(.requires_device, true),
-        FIELD_INIT(.requires_fpga, false),
-        FIELD_INIT(.allow_while_streaming, false),
-    },
     {
         FIELD_INIT(.names, cmd_names_help),
         FIELD_INIT(.exec, cmd_help),
@@ -194,16 +173,18 @@ static const struct cmd cmd_table[] = {
     {
         FIELD_INIT(.names, cmd_names_info),
         FIELD_INIT(.exec, cmd_info),
-        FIELD_INIT(.desc, "Print information about the currently opened device"),
+        FIELD_INIT(.desc, "Print information about the currently opened "
+                          "device"),
         FIELD_INIT(.help, CLI_CMD_HELPTEXT_info),
         FIELD_INIT(.requires_device, true),
         FIELD_INIT(.requires_fpga, false),
         FIELD_INIT(.allow_while_streaming, true),
     },
     {
-        FIELD_INIT(.names, cmd_names_jump),
+        FIELD_INIT(.names, cmd_names_jump_to_bootloader),
         FIELD_INIT(.exec, cmd_jump_to_bootloader),
-        FIELD_INIT(.desc, "Clear FW signature in flash and jump to FX3 bootloader"),
+        FIELD_INIT(.desc, "Clear FW signature in flash and jump to FX3 "
+                          "bootloader"),
         FIELD_INIT(.help, CLI_CMD_HELPTEXT_jump_to_boot),
         FIELD_INIT(.requires_device, true),
         FIELD_INIT(.requires_fpga, false),
@@ -218,15 +199,6 @@ static const struct cmd cmd_table[] = {
         FIELD_INIT(.requires_fpga, false),
         FIELD_INIT(.allow_while_streaming, false),
     },
-    {
-        FIELD_INIT(.names, cmd_names_xb),
-        FIELD_INIT(.exec, cmd_xb),
-        FIELD_INIT(.desc, "Enable and configure expansion boards"),
-        FIELD_INIT(.help, CLI_CMD_HELPTEXT_xb),
-        FIELD_INIT(.requires_device, true),
-        FIELD_INIT(.requires_fpga, true),
-        FIELD_INIT(.allow_while_streaming, false),
-    },
     {
         FIELD_INIT(.names, cmd_names_mimo),
         FIELD_INIT(.exec, cmd_mimo),
@@ -283,7 +255,7 @@ static const struct cmd cmd_table[] = {
     },
     {
         FIELD_INIT(.names, cmd_names_quit),
-        FIELD_INIT(.exec, NULL), /* Default action on NULL exec function is to quit */
+        FIELD_INIT(.exec, NULL), /* Default action on NULL exec fn is to quit */
         FIELD_INIT(.desc, "Exit the CLI"),
         FIELD_INIT(.help, CLI_CMD_HELPTEXT_quit),
         FIELD_INIT(.requires_device, false),
@@ -291,9 +263,10 @@ static const struct cmd cmd_table[] = {
         FIELD_INIT(.allow_while_streaming, true),
     },
     {
-        FIELD_INIT(.names, cmd_names_rec),
+        FIELD_INIT(.names, cmd_names_recover),
         FIELD_INIT(.exec, cmd_recover),
-        FIELD_INIT(.desc, "Load firmware when operating in FX3 bootloader mode"),
+        FIELD_INIT(.desc, "Load firmware when operating in FX3 bootloader "
+                          "mode"),
         FIELD_INIT(.help, CLI_CMD_HELPTEXT_recover),
         FIELD_INIT(.requires_device, false),
         FIELD_INIT(.requires_fpga, false),
@@ -317,6 +290,15 @@ static const struct cmd cmd_table[] = {
         FIELD_INIT(.requires_fpga, true),
         FIELD_INIT(.allow_while_streaming, true),   /* Can rx while tx'ing */
     },
+    {
+        FIELD_INIT(.names, cmd_names_set),
+        FIELD_INIT(.exec, cmd_set),
+        FIELD_INIT(.desc, "Set device settings"),
+        FIELD_INIT(.help, CLI_CMD_HELPTEXT_set),
+        FIELD_INIT(.requires_device, true),
+        FIELD_INIT(.requires_fpga, true),
+        FIELD_INIT(.allow_while_streaming, true),
+    },
     {
         FIELD_INIT(.names, cmd_names_trigger),
         FIELD_INIT(.exec, cmd_trigger),
@@ -324,7 +306,8 @@ static const struct cmd cmd_table[] = {
         FIELD_INIT(.help, CLI_CMD_HELPTEXT_trigger),
         FIELD_INIT(.requires_device, true),
         FIELD_INIT(.requires_fpga, true),
-        FIELD_INIT(.allow_while_streaming, true),   /* Can control trigger while running */
+        FIELD_INIT(.allow_while_streaming, true),   /* Can control trigger 
+                                                     * while running */
     },
     {
         FIELD_INIT(.names, cmd_names_tx),
@@ -336,16 +319,7 @@ static const struct cmd cmd_table[] = {
         FIELD_INIT(.allow_while_streaming, true),   /* Can tx while rx'ing */
     },
     {
-        FIELD_INIT(.names, cmd_names_set),
-        FIELD_INIT(.exec, cmd_set),
-        FIELD_INIT(.desc, "Set device settings"),
-        FIELD_INIT(.help, CLI_CMD_HELPTEXT_set),
-        FIELD_INIT(.requires_device, true),
-        FIELD_INIT(.requires_fpga, true),
-        FIELD_INIT(.allow_while_streaming, true),
-    },
-    {
-        FIELD_INIT(.names, cmd_names_ver),
+        FIELD_INIT(.names, cmd_names_version),
         FIELD_INIT(.exec, cmd_version),
         FIELD_INIT(.desc, "Host software and device version information"),
         FIELD_INIT(.help, CLI_CMD_HELPTEXT_version),
@@ -353,6 +327,15 @@ static const struct cmd cmd_table[] = {
         FIELD_INIT(.requires_fpga, false),
         FIELD_INIT(.allow_while_streaming, true),
     },
+    {
+        FIELD_INIT(.names, cmd_names_xb),
+        FIELD_INIT(.exec, cmd_xb),
+        FIELD_INIT(.desc, "Enable and configure expansion boards"),
+        FIELD_INIT(.help, CLI_CMD_HELPTEXT_xb),
+        FIELD_INIT(.requires_device, true),
+        FIELD_INIT(.requires_fpga, true),
+        FIELD_INIT(.allow_while_streaming, false),
+    },
     /* Always terminate the command entry with a completely NULL entry */
     {
         FIELD_INIT(.names, NULL),
@@ -364,23 +347,27 @@ static const struct cmd cmd_table[] = {
         FIELD_INIT(.allow_while_streaming, true),
     }
 };
+// clang-format on
 
-const struct numeric_suffix freq_suffixes[NUM_FREQ_SUFFIXES] = {
+// clang-format off
+struct numeric_suffix const freq_suffixes[NUM_FREQ_SUFFIXES] = {
     { "G",      1000 * 1000 * 1000 },
     { "GHz",    1000 * 1000 * 1000 },
     { "M",      1000 * 1000 },
     { "MHz",    1000 * 1000 },
-    { "k",      1000 } ,
+    { "k",      1000 },
     { "kHz",    1000 }
 };
+// clang-format on
 
-const struct cmd *get_cmd( char *name )
+struct cmd const *get_cmd(char *name)
 {
-    const struct cmd *rv = NULL;
-    int i = 0, j = 0 ;
-    for( i = 0; cmd_table[i].names != NULL && rv == 0; i++ ) {
-        for( j = 0; cmd_table[i].names[j] != NULL && rv == 0; j++ ) {
-            if( strcasecmp( name, cmd_table[i].names[j] ) == 0 ) {
+    struct cmd const *rv = NULL;
+    int i, j;
+
+    for (i = 0; cmd_table[i].names != NULL && rv == 0; ++i) {
+        for (j = 0; cmd_table[i].names[j] != NULL && rv == 0; ++j) {
+            if (strcasecmp(name, cmd_table[i].names[j]) == 0) {
                 rv = &(cmd_table[i]);
             }
         }
@@ -391,29 +378,30 @@ const struct cmd *get_cmd( char *name )
 
 int cmd_help(struct cli_state *s, int argc, char **argv)
 {
-    int i = 0;
+    struct cmd const *cmd = NULL;
+    int i;
     int ret = CLI_RET_OK;
-    const struct cmd *cmd;
 
     /* Asking for general help */
-    if( argc == 1 ) {
-        printf( "\n" );
-        for( i = 0; cmd_table[i].names != NULL; i++ ) {
+    if (1 == argc) {
+        printf("\n");
+        for (i = 0; cmd_table[i].names != NULL; ++i) {
             /* Hidden functions for fun and profit */
-            if( cmd_table[i].names[0][0] == '_' ) continue;
-            printf( "  %-20s%s\n", cmd_table[i].names[0], cmd_table[i].desc );
+            if (cmd_table[i].names[0][0] == '_') {
+                continue;
+            }
+            printf("  %-20s%s\n", cmd_table[i].names[0], cmd_table[i].desc);
         }
-        printf( "\n" );
-
-    /* Asking for command specific help */
-    } else if( argc == 2 ) {
+        printf("\n");
 
+        /* Asking for command specific help */
+    } else if (2 == argc) {
         /* Iterate through the commands */
         cmd = get_cmd(argv[1]);
 
         /* If we found it, print the help */
-        if( cmd ) {
-            printf( "\n%s\n", cmd->help );
+        if (NULL != cmd) {
+            printf("\n%s\n", cmd->help);
         } else {
             /* Otherwise, print that we couldn't find it :( */
             cli_err(s, argv[0], "No help info available for \"%s\"\n", argv[1]);
@@ -441,9 +429,9 @@ int cmd_run(struct cli_state *state, int argc, char **argv)
 
     status = cli_open_script(&state->scripts, argv[1]);
 
-    if (status == 0) {
+    if (0 == status) {
         return CLI_RET_RUN_SCRIPT;
-    } else if (status == 1) {
+    } else if (1 == status) {
         cli_err(state, "run", "Recursive loop detected in script.\n");
         return CLI_RET_INVPARAM;
     } else if (status < 0) {
@@ -462,23 +450,23 @@ int cmd_echo(struct cli_state *state, int argc, char **argv)
 {
     int i;
 
-    for (i = 1; i < argc; i++) {
+    for (i = 1; i < argc; ++i) {
         printf("%s\n", argv[i]);
     }
 
     return 0;
 }
 
-int cmd_handle(struct cli_state *s, const char *line)
+int cmd_handle(struct cli_state *s, char const *line)
 {
-    const struct cmd *cmd;
-    int argc, ret;
-    char **argv = NULL;
+    struct cmd const *cmd;
+    int argc;
+    int ret         = 0;
+    char **argv     = NULL;
     int fpga_status = -1;
 
-    ret = 0;
     argc = str2args(line, COMMENT_CHAR, &argv);
-    if (argc == -2) {
+    if (-2 == argc) {
         cli_err(s, "Error", "Input contains unterminated quote.\n");
         return CLI_RET_INVPARAM;
     }
@@ -494,15 +482,16 @@ int cmd_handle(struct cli_state *s, const char *line)
                 }
 
                 /* Check if the command requires a loaded FPGA */
-                if (ret == 0 && cmd->requires_fpga) {
+                if (0 == ret && cmd->requires_fpga) {
                     fpga_status = bladerf_is_fpga_configured(s->dev);
                     if (fpga_status < 0) {
                         cli_err(s, argv[0],
                                 "Failed to determine if the FPGA is configured:"
-                                " %s\n", bladerf_strerror(fpga_status));
+                                " %s\n",
+                                bladerf_strerror(fpga_status));
 
                         s->last_lib_error = fpga_status;
-                        ret = CLI_RET_LIBBLADERF;
+                        ret               = CLI_RET_LIBBLADERF;
                     } else if (fpga_status != 1) {
                         ret = CLI_RET_NOFPGA;
                     }
@@ -510,12 +499,12 @@ int cmd_handle(struct cli_state *s, const char *line)
 
                 /* Test if this command may be run while the device is
                  * actively running an RX/TX stream */
-                if (ret == 0 &&
-                    cli_device_is_streaming(s) && !cmd->allow_while_streaming) {
+                if (0 == ret && cli_device_is_streaming(s) &&
+                    !cmd->allow_while_streaming) {
                     ret = CLI_RET_BUSY;
                 }
 
-                if (ret == 0) {
+                if (0 == ret) {
                     /* Commands own the device handle while they're executing.
                      * This is needed to prevent races on the device handle
                      * while the RX/TX make any necessary control calls while
@@ -533,7 +522,7 @@ int cmd_handle(struct cli_state *s, const char *line)
         }
 
         free_args(argc, argv);
-    } else if (argc == 0) {
+    } else if (0 == argc) {
         free_args(argc, argv);
     } else {
         ret = CLI_RET_UNKNOWN;
@@ -542,9 +531,10 @@ int cmd_handle(struct cli_state *s, const char *line)
     return ret;
 }
 
-void cmd_show_help_all() {
+void cmd_show_help_all()
+{
     int i = 0;
-    for( i = 0; cmd_table[i].names != NULL; i++ )
+
+    for (i = 0; cmd_table[i].names != NULL; ++i)
         printf("COMMAND: %s\n", cmd_table[i].help);
 }
-
